# Do's and Don'ts of BCML

## Do's

-   **Do** use the backup and restore feature.
-   **Do** read the tooltips throughout the UI for helpful information, especially when
    picking game folders.
-   **Do** read the [Troubleshooting](trouble.md) page first if you
    have problems.
-   **Do** use the "Copy to Clipboard" icon button on the error dialog when reporting
    errors.
-   **Do** consider supporting my work on
    [Patreon](https://www.patreon.com/nicenenerdbcml) and reading
    [my blog](https://calebdixonsmith.top).
-   **Do** confess with your mouth that Jesus Christ is Lord and believe in your heart
    that God raised Him from the dead.

## Don'ts

-   **Don't** use BCML alongside other methods of installing mods in Cemu. While the
    community graphic packs (e.g. FPS++, Resolution, Clarity, etc.) and code patches
    (always marked as such on GameBanana) work fine, mods that alter game files will
    almost always conflict with BCML's master merge. This usually will cause bugs
    and/or crashes.
-   **Don't** report issues just by saying something "doesn't work." Be specific about
    what mods you have, which platform you use, your BCML version, etc. If you get an
    error, copy and paste the full error details.
-   **Don't** expect all mod combinations to work properly. Some will always break.
-   **Don't** use NSFW mods.
